==> mobile_pos-1.1.1.tar.gz: lib/src/views/dispute/dispute_type_sheet.dart <==
import 'package:flutter/material.dart';
import 'package:gap/gap.dart';
import 'package:mobile_pos/src/helpers/global_variables.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_bottomsheet_capsule.dart';
import 'package:mobile_pos/src/styles/ravenpay_app_colors.dart';
import 'package:mobile_pos/src/styles/ravenpay_textstyles.dart';
import 'package:mobile_pos/src/views/terminal/view_info_screen.dart';

class SelectDisputeTypeSheet extends StatelessWidget {
  SelectDisputeTypeSheet({super.key});
  final List<String> issues = [
    "Missing Balance",
    "Card Payment Failed",
    "Card Charged Twice"
  ];
  @override
  Widget build(BuildContext context) {
    return Container(
      padding: EdgeInsets.symmetric(horizontal: kHorizontalScreenPadding),
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        mainAxisSize: MainAxisSize.min,
        children: [
          const Gap(20),
          const RavenPayBottomSheetCapsule(),
          const Gap(24),
          Row(
            children: [
              Expanded(
                  child: Text("Dispute Type",
                      style: headling1.copyWith(fontSize: 20))),
              GestureDetector(
                onTap: () {
                  Navigator.pop(context);
                },
                child: RoundedItemContainer(
                    asset: "cancel_icon.png",
                    imageColor: pluginTheme.isLightTheme ? null : Colors.white),
              )
            ],
          ),
          const Gap(20),
          ...issues.map((e) => GestureDetector(
                onTap: () => Navigator.pop(context, e),
                child: Container(
                  width: double.infinity,
                  decoration: BoxDecoration(
                      border: Border(
                          bottom: BorderSide(
                              color: AppColors.ravenLightGrey.withOpacity(
                                  pluginTheme.isLightTheme ? 0.7 : 0.08)))),
                  padding: const EdgeInsets.symmetric(vertical: 20),
                  child: Text(e,
                      style: subtitle.copyWith(
                          fontWeight: FontWeight.w500, fontSize: 16)),
                ),
              )),
          const Gap(24),
        ],
      ),
    );
  }
}

==> mobile_pos-2.0.0.tar.gz: lib/src/views/dispute/dispute_type_sheet.dart <==
import 'package:flutter/material.dart';
import 'package:gap/gap.dart';
import 'package:mobile_pos/src/helpers/global_variables.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_bottomsheet_capsule.dart';
import 'package:mobile_pos/src/styles/ravenpay_app_colors.dart';
import 'package:mobile_pos/src/styles/ravenpay_textstyles.dart';
import 'package:mobile_pos/src/views/terminal/view_terminal_details.dart';

class SelectDisputeTypeSheet extends StatelessWidget {
  SelectDisputeTypeSheet({super.key});
  final List<String> issues = [
    "Missing Balance",
    "Card Payment Failed",
    "Card Charged Twice"
  ];
  @override
  Widget build(BuildContext context) {
    return Container(
      padding: EdgeInsets.symmetric(horizontal: kHorizontalScreenPadding),
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        mainAxisSize: MainAxisSize.min,
        children: [
          const Gap(20),
          const RavenPayBottomSheetCapsule(),
          const Gap(24),
          Row(
            children: [
              Expanded(
                  child: Text("Dispute Type",
                      style: headling1.copyWith(fontSize: 20))),
              GestureDetector(
                onTap: () {
                  Navigator.pop(context);
                },
                child: RoundedItemContainer(
                    asset: "cancel_icon.png",
                    imageColor: pluginTheme.isLightTheme ? null : Colors.white),
              )
            ],
          ),
          const Gap(20),
          ...issues.map((e) => GestureDetector(
                onTap: () => Navigator.pop(context, e),
                child: Container(
                  width: double.infinity,
                  decoration: BoxDecoration(
                      border: Border(
                          bottom: BorderSide(
                              color: AppColors.ravenLightGrey.withOpacity(
                                  pluginTheme.isLightTheme ? 0.7 : 0.08)))),
                  padding: const EdgeInsets.symmetric(vertical: 20),
                  child: Text(e,
                      style: subtitle.copyWith(
                          fontWeight: FontWeight.w500, fontSize: 16)),
                ),
              )),
          const Gap(24),
        ],
      ),
    );
  }
}
